@@ -21,3 +21,16 @@ test_that("array_index is correct", {
   mat <- matrix(c(1,1,1,2,3,1,3,4,2), nrow = 3)
   expect_equal(array_index(c(1,8,24), dims), mat)
 })
+
+test_that("vec_index and array_index are inverses of each other", {
+  dims <- c(2,3,4)
+  i <- 1:24
+
+  expect_equal(vec_index(array_index(i, dims), dims), i)
+})
+
+test_that("fill missing indices is correct", {
+  expect_equal(fill_missing_indices(1, 10), 1)
+  expect_equal(fill_missing_indices(NULL, 10), 1:10)
+  expect_equal(fill_missing_indices(-5, 10), c(1:4, 6:10))
+})
